@@ -1,6 +1,6 @@
 package Statocles::Command;
 # ABSTRACT: The statocles command-line interface
-$Statocles::Command::VERSION = '0.051';
+$Statocles::Command::VERSION = '0.052';
 use Statocles::Base 'Class';
 use Scalar::Util qw( blessed );
 use Getopt::Long qw( GetOptionsFromArray :config pass_through bundling no_auto_abbrev );
@@ -242,11 +242,11 @@ sub create_site {
     my ( $site ) = YAML::Load( $create_dir->child( 'site.yml' )->slurp_utf8 );
 
     if ( $answer{flavor} == 1 ) {
-        $site->{site}{args}{index} = "blog";
+        $site->{site}{args}{index} = "/blog";
         $site->{site}{args}{nav}{main}[0]{href} = "/";
     }
     elsif ( $answer{flavor} == 2 ) {
-        $site->{site}{args}{index} = "page";
+        $site->{site}{args}{index} = "/page";
         $site->{site}{args}{nav}{main}[0]{href} = "/blog";
     }
 
@@ -470,7 +470,7 @@ Statocles::Command - The statocles command-line interface
 
 =head1 VERSION
 
-version 0.051
+version 0.052
 
 =head1 SYNOPSIS
 
