@@ -1,14 +1,14 @@
 package Statocles::Deploy::File;
 # ABSTRACT: Deploy a site to a folder on the filesystem
-$Statocles::Deploy::File::VERSION = '0.051';
+$Statocles::Deploy::File::VERSION = '0.052';
 use Statocles::Base 'Class';
 with 'Statocles::Deploy';
 
 
 has path => (
     is => 'ro',
-    isa => Dir,
-    coerce => Dir->coercion,
+    isa => Path,
+    coerce => Path->coercion,
     default => sub { Path::Tiny->new( '.' ) },
 );
 
@@ -16,6 +16,10 @@ has path => (
 sub deploy {
     my ( $self, $from_store, $message ) = @_;
 
+    die sprintf 'Deploy directory "%s" does not exist (did you forget to make it?)',
+        $self->path
+            if !$self->path->is_dir;
+
     my @files;
     my $iter = $from_store->find_files( include_documents => 1 );
     while ( my $path = $iter->() ) {
@@ -45,7 +49,7 @@ Statocles::Deploy::File - Deploy a site to a folder on the filesystem
 
 =head1 VERSION
 
-version 0.051
+version 0.052
 
 =head1 DESCRIPTION
 
