@@ -1,6 +1,6 @@
 package Statocles::Site;
 # ABSTRACT: An entire, configured website
-$Statocles::Site::VERSION = '0.051';
+$Statocles::Site::VERSION = '0.052';
 use Statocles::Base 'Class', 'Emitter';
 use Scalar::Util qw( blessed );
 use Text::Markdown;
@@ -130,10 +130,6 @@ has _write_deploy => (
 sub BUILD {
     my ( $self ) = @_;
 
-    if ( $self->index && !$self->app( $self->index ) ) {
-        die sprintf 'ERROR: Index app "%s" does not exist', $self->index;
-    }
-
     $Statocles::SITE = $self;
     for my $app ( values %{ $self->apps } ) {
         $app->site( $self );
@@ -173,11 +169,22 @@ sub build {
     );
 
     # Collect all the pages for this site
+    # XXX: Should we allow sites without indexes?
+    my $index_path = $self->index;
+    if ( $index_path && $index_path !~ m{^/} ) {
+        $self->log->warn(
+            sprintf 'site "index" property should be absolute path to index page (got "%s")',
+            $self->index,
+        );
+    }
+
     for my $app_name ( keys %{ $apps } ) {
         my $app = $apps->{$app_name};
 
         my @app_pages = $app->pages;
-        if ( $self->index eq $app_name ) {
+
+        # DEPRECATED: Index as app name
+        if ( $app_name eq $index_path ) {
 
             die sprintf 'ERROR: Index app "%s" did not generate any pages' . "\n", $self->index
                 unless @app_pages;
@@ -190,6 +197,18 @@ sub build {
         for my $page ( @app_pages ) {
             my $path = $page->path;
 
+            if ( $path =~ m{^$index_path(?:/index[.]html)?$} ) {
+                # Rename the app's page so that we don't get two pages with identical
+                # content, which is bad for SEO
+                $self->log->debug(
+                    sprintf 'Found index page "%s" from app "%s"',
+                    $path,
+                    $app_name,
+                );
+                $path = '/index.html';
+                $page->path( '/index.html' );
+            }
+
             if ( $seen_paths{ $path }{ $app_name } ) {
                 $self->log->warn(
                     sprintf 'Duplicate page with path "%s" from app "%s"',
@@ -203,6 +222,11 @@ sub build {
         }
     }
 
+    # XXX: Do we want to allow sites with no index page ever?
+    if ( $self->index && !exists $seen_paths{ '/index.html' } ) {
+        die sprintf qq{ERROR: Index path "%s" does not exist}, $self->index
+    }
+
     for my $path ( keys %seen_paths ) {
         my %seen_apps = %{ $seen_paths{$path} };
         # Warn about pages generated by more than one app
@@ -241,7 +265,11 @@ sub build {
     my $base_path = Mojo::URL->new( $base_url )->path;
     $base_path =~ s{/$}{};
 
-    my $index_root = $self->index ? $apps->{ $self->index }->url_root : '';
+    # DEPRECATED: Index without leading / is an index app
+    my $index_root  = $self->index =~ m{^/} ? $self->index
+                    : $self->index ? $apps->{ $self->index }->url_root : '';
+    $index_root =~ s{/index[.]html$}{};
+
     for my $page ( @pages ) {
         my $content = $page->render( %args );
 
@@ -345,7 +373,7 @@ Statocles::Site - An entire, configured website
 
 =head1 VERSION
 
-version 0.051
+version 0.052
 
 =head1 SYNOPSIS
 
@@ -389,8 +417,8 @@ that can be used later.
 
 =head2 index
 
-The application to use as the site index. The application's individual index()
-method will be called to get the index page.
+The page path to use for the site index. Make sure to include the leading
+slash (but C</index.html> is optional).
 
 =head2 nav
 
