@@ -1,6 +1,6 @@
 package Statocles::Test;
 # ABSTRACT: Common test routines for Statocles
-$Statocles::Test::VERSION = '0.051';
+$Statocles::Test::VERSION = '0.052';
 use Statocles::Base;
 use Test::More;
 use Test::Exception;
@@ -132,8 +132,7 @@ sub test_pages {
         %opt = %{ +shift };
     }
 
-    my ( $index_path, $index_test, %page_tests ) = @_;
-    $page_tests{ $index_path } = $index_test;
+    my %page_tests = @_;
 
     local $Test::Builder::Level = $Test::Builder::Level + 1;
 
@@ -144,10 +143,6 @@ sub test_pages {
 
     is scalar @pages, scalar keys %page_tests, 'correct number of pages';
 
-    if ( !$opt{noindex} ) {
-        is $pages[0]->path, $index_path, 'index page must come first';
-    }
-
     for my $page ( @pages ) {
         ok $page->DOES( 'Statocles::Page' ), 'must be a Statocles::Page';
 
@@ -245,7 +240,7 @@ sub build_temp_site {
             class => 'Statocles::Site',
             args => {
                 title => 'Site Title',
-                index => 'blog',
+                index => '/blog',
                 build_store => { '$ref' => 'build' },
                 deploy => { '$ref' => 'deploy' },
                 theme => { '$ref' => 'theme' },
@@ -274,7 +269,7 @@ sub build_temp_site {
             class => 'Statocles::Site',
             args => {
                 title => 'Site Foo',
-                index => 'blog',
+                index => '/blog',
                 build_store => { '$ref' => 'build_foo' },
                 deploy => { '$ref' => 'deploy_foo' },
                 theme => '::default',
@@ -303,7 +298,7 @@ Statocles::Test - Common test routines for Statocles
 
 =head1 VERSION
 
-version 0.051
+version 0.052
 
 =head1 DESCRIPTION
 
